searchData={"items":[{"type":"module","title":"SimpleMemCache","doc":"In-memory key-value cache with expiration-time after creation/modification/access,\nautomatic value loading and time travel support.","ref":"SimpleMemCache.html"},{"type":"module","title":"Prepare ETS table to be used by SimpleMemCache - SimpleMemCache","doc":"Example 1: plain ETS:\n\n  ```elixir\n  tid = :ets.new(__MODULE__, [:set,\n                               :public,\n                              {:read_concurrency,  true},\n                              {:write_concurrency, true}\n                             ])\n  ```\n\nExample 2: use [Eternal](https://hex.pm/packages/eternal) to create the ETS table:\n\n  ```elixir\n\n  defmodule MyProject do\n    use Application\n\n    def start(_type, _args) do\n      import Supervisor.Spec, warn: false\n\n      Eternal.start_link(SimpleMemCache,\n                         [:set,\n                          {:read_concurrency,  true},\n                          {:write_concurrency, true}\n                         ])\n\n  ```\n\nOnly ETS types: set and ordered_set are supported.","ref":"SimpleMemCache.html#module-prepare-ets-table-to-be-used-by-simplememcache"},{"type":"module","title":"Usage - SimpleMemCache","doc":"#","ref":"SimpleMemCache.html#module-usage"},{"type":"module","title":"Keep in cache for a limited time, automatically load new value after that - SimpleMemCache","doc":"- Example: scrape news and keep it 10 minutes in cache\n\n    ```elixir\n    us_news = SimpleMemCache.cache(SimpleMemCache, \"news_us\", 10,\n                                   &Scraper.scrape_news_us/0)\n    ```\n\n  - or with anonymous function:\n\n      ```elixir\n      def news(country) do\n        SimpleMemCache.cache(SimpleMemCache, \"news_\" <> country, 10,\n                             fn -> Scraper.scrape_news(country) end)\n      end\n      ```\n\nNote about automatically new value loading:\n- How long does this function take to get the new value, and is this acceptable when the old value is expired? If it takes too long, consider to use an scheduler to regularly recalculate the new value and update the cache with that.\n\n#","ref":"SimpleMemCache.html#module-keep-in-cache-for-a-limited-time-automatically-load-new-value-after-that"},{"type":"module","title":"Keep in cache for a limited time but extend life-time everytime it is accessed - SimpleMemCache","doc":"- Example: cache http response of countries rest service for at least 20 minutes\n\n    ```elixir\n    countries_response = SimpleMemCache.cache(SimpleMemCache,\n             \"countries_response\",\n             20,\n             true,\n             fn -> HTTPoison.get! \"http://restcountries.eu/rest/v1/\" end)\n    ```\n\n#","ref":"SimpleMemCache.html#module-keep-in-cache-for-a-limited-time-but-extend-life-time-everytime-it-is-accessed"},{"type":"module","title":"Keep as long as the ETS table exists - SimpleMemCache","doc":"- Example: Cache products retrieved from csv file. Not a good example, because nowadays files are stored on SSD and there will be no performance gain.\n\n    ```elixir\n    products = SimpleMemCache.cache(SimpleMemCache, \"products\", fn -> \"products.csv\"\n                                                                      |> File.stream!\n                                                                      |> CSV.parse_stream\n                                                                      |> Enum.to_list\n                                                                end)\n    ```\n\n  - updates are still possible:\n\n    ```elixir\n    SimpleMemCache.put(SimpleMemCache, \"products\", new_value)\n    ```\n\nor you can force an automatically load at first access by invalidating the cached item.\n\n#","ref":"SimpleMemCache.html#module-keep-as-long-as-the-ets-table-exists"},{"type":"module","title":"Invalidate cached item - SimpleMemCache","doc":"- Example: remove products from cache\n\n    ```elixir\n    old_value = SimpleMemCache.remove(SimpleMemCache, \"products\")\n    ```","ref":"SimpleMemCache.html#module-invalidate-cached-item"},{"type":"function","title":"SimpleMemCache.cache/5","doc":"Cache value returned by the supplied function.\n\n* `table` - Name of the ETS table.\n* `key` - Key name\n* `minutes_valid` - Minutes to keep the item in cache. Default: nil - do not expire.\n* `keep_alive` - Keep the item in cache if it still accessed. It expires if it is not retrieved in `minutes_valid` minutes. Default: false\n* `f_new_value` - function that supplies the value. Enables automatic value loading. When `minutes_valid` is not nil and `keep_alive` is false, this function can be launched in a new Erlang process, and it can do this proactively up to 30 seconds before expiration.","ref":"SimpleMemCache.html#cache/5"},{"type":"function","title":"Examples - SimpleMemCache.cache/5","doc":"products = SimpleMemCache.cache(SimpleMemCache, \"products\", 30, true,\n       fn() -> File.read!(filename) end\n    )\n\n    news_page = SimpleMemCache.cache(SimpleMemCache, \"news\", 10, &scrape_news/0)","ref":"SimpleMemCache.html#cache/5-examples"},{"type":"function","title":"SimpleMemCache.get/3","doc":"Get status and value of cached item. Status can be :ok, :expired or :not_cached\n\nThe `minutes_keep_alive` parameter is the number of minutes to keep the item at least in cache.\nDoes not shorten a previously set expiration time (use put for that). However,\nif there wasn't an expiration time it will take the new value. Default: nil - do not change the expire time.","ref":"SimpleMemCache.html#get/3"},{"type":"function","title":"Example - SimpleMemCache.get/3","doc":"iex(1)> products = SimpleMemCache.get(SimpleMemCache, \"products\", 20)\n    {:expired, \"Fret dots\"}","ref":"SimpleMemCache.html#get/3-example"},{"type":"function","title":"SimpleMemCache.get!/3","doc":"Get value of cached item. Nil if is not cached or when value is nil.","ref":"SimpleMemCache.html#get!/3"},{"type":"function","title":"SimpleMemCache.get_system_time_function/1","doc":"Returns function that generates Unix/Posix UTC time in seconds.","ref":"SimpleMemCache.html#get_system_time_function/1"},{"type":"function","title":"SimpleMemCache.put/4","doc":"Create or update an item in cache.","ref":"SimpleMemCache.html#put/4"},{"type":"function","title":"SimpleMemCache.remove/2","doc":"Remove an item from cache. Returns the value of the removed object.","ref":"SimpleMemCache.html#remove/2"},{"type":"function","title":"SimpleMemCache.remove_expired_entries/1","doc":"Remove expired entries. This is automatically called once a minute during SimpleMemCache usage.","ref":"SimpleMemCache.html#remove_expired_entries/1"},{"type":"function","title":"SimpleMemCache.set_system_time_function/2","doc":"Time travel for SimpleMemCache.\n\nThe `f_system_time` parameter is meant for time travel support.\nYou can provide a function that returns the Unix/Posix UTC time in seconds.\nSet nil to restore the normal system time.","ref":"SimpleMemCache.html#set_system_time_function/2"},{"type":"function","title":"SimpleMemCache.stop/1","doc":"Delete the ETS table.","ref":"SimpleMemCache.html#stop/1"},{"type":"type","title":"SimpleMemCache.table/0","doc":"The table id (Tid) or table name","ref":"SimpleMemCache.html#t:table/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}